package com.younike.system.mapper;

import com.younike.system.domain.SysTreaty;

import java.util.List;

/**
 * 隐私协议Mapper接口
 *
 * @author elev
 * @date 2022-01-04
 */
public interface SysTreatyMapper
{
    /**
     * 查询隐私协议
     *
     * @param id 隐私协议主键
     * @return 隐私协议
     */
    public SysTreaty selectSysTreatyById(Long id);

    /**
     * 查询隐私协议列表
     *
     * @param sysTreaty 隐私协议
     * @return 隐私协议集合
     */
    public List<SysTreaty> selectSysTreatyList(SysTreaty sysTreaty);

    /**
     * 新增隐私协议
     *
     * @param sysTreaty 隐私协议
     * @return 结果
     */
    public int insertSysTreaty(SysTreaty sysTreaty);

    /**
     * 修改隐私协议
     *
     * @param sysTreaty 隐私协议
     * @return 结果
     */
    public int updateSysTreaty(SysTreaty sysTreaty);

    /**
     * 删除隐私协议
     *
     * @param id 隐私协议主键
     * @return 结果
     */
    public int deleteSysTreatyById(Long id);

    /**
     * 批量删除隐私协议
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysTreatyByIds(Long[] ids);

}

